Gumbel

Struct Gumbel 

pub struct Gumbel { /* private fields */ }
Implements the Gumbel distribution, also known as the type-I generalized extreme value distribution.

Examples

use statrs::distribution::{Gumbel, Continuous};
use statrs::{consts::EULER_MASCHERONI, statistics::Distribution};

let n = Gumbel::new(0.0, 1.0).unwrap();
assert_eq!(n.location(), 0.0);
assert_eq!(n.skewness().unwrap(), 1.13955);
assert_eq!(n.pdf(0.0), 0.36787944117144233);

Implementations

Source

impl Gumbel

pub fn new(location: f64, scale: f64) -> Result<Self, GumbelError>

Constructs a new Gumbel distribution with the given location and scale.

Errors

Returns an error if location or scale are NaN or scale <= 0.0

Examples
use statrs::distribution::Gumbel;

let mut result = Gumbel::new(0.0, 1.0);
assert!(result.is_ok());

result = Gumbel::new(0.0, -1.0);
assert!(result.is_err());
pub fn location(&self) -> f64

Returns the location of the Gumbel distribution

Examples
use statrs::distribution::Gumbel;

let n = Gumbel::new(0.0, 1.0).unwrap();
assert_eq!(n.location(), 0.0);
pub fn scale(&self) -> f64

Returns the scale of the Gumbel distribution

Examples
use statrs::distribution::Gumbel;

let n = Gumbel::new(0.0, 1.0).unwrap();
assert_eq!(n.scale(), 1.0);